@@ -136,17 +136,23 @@ function solve_call(_prob, args...; merge_callbacks = true, kwargshandle = nothi
     end
 
     checkkwargs(kwargshandle; kwargs...)
+
+    # Check bounds support for problems with bounds
+    if (_prob isa SciMLBase.NonlinearProblem || _prob isa SciMLBase.NonlinearLeastSquaresProblem) &&
+       (hasfield(typeof(_prob), :lb) && hasfield(typeof(_prob), :ub)) &&
+       (_prob.lb !== nothing || _prob.ub !== nothing) &&
+       length(args) > 0 && !SciMLBase.allowsbounds(args[1])
+        error("Algorithm $(args[1]) does not support bounds. Use an algorithm with allowsbounds(alg) == true.")
+    end
+
     if isdefined(_prob, :u0)
         if _prob.u0 isa Array
             if !isconcretetype(RecursiveArrayTools.recursive_unitless_eltype(_prob.u0))
                 throw(NonConcreteEltypeError(RecursiveArrayTools.recursive_unitless_eltype(_prob.u0)))
             end
 
-            if !(eltype(_prob.u0) <: Number) && !(eltype(_prob.u0) <: Enum) &&
-               !(_prob.u0 isa AbstractVector{<:AbstractArray} && _prob isa BVProblem)
-                # Allow Enums for FunctionMaps, make into a trait in the future
-                # BVPs use Vector of Arrays for initial guesses
-                throw(NonNumberEltypeError(eltype(_prob.u0)))
+            if !(eltype(_prob.u0) <: Number) && !(eltype(_prob.u0) <: Enum)
+                throw(SciMLBase.NonNumberEltypeError(eltype(_prob.u0)))
             end
         end
 
